==> beast-privilege-api-2.9.14-GS-20241029.091149-2-sources.jar: com/thebeastshop/privilege/cond/StoremanTaskmanagerDetailCond.java <==
package com.thebeastshop.privilege.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.List;

/**
 * Created by gensheng.ye on 2022/8/30.
 */
public class StoremanTaskmanagerDetailCond extends BaseQueryCond {

    private Integer taskId;



    /*
               渠道
              */
    private List<String> channelCodes;

    /*
     是否指派
     */
    private Integer assigned;


    /*
       手机号
     */
    private String mobile;

    /*
      负责人
     */
    private Integer userId;

    private Integer processClass;

    private Integer type;

    private Integer hasGroupTypeCount;

    public Integer getTaskId() {
        return taskId;
    }

    public void setTaskId(Integer taskId) {
        this.taskId = taskId;
    }


    public List<String> getChannelCodes() {
        return channelCodes;
    }

    public void setChannelCodes(List<String> channelCodes) {
        this.channelCodes = channelCodes;
    }

    public Integer getAssigned() {
        return assigned;
    }

    public void setAssigned(Integer assigned) {
        this.assigned = assigned;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Integer getUserId() {
        return userId;
    }

    public void setUserId(Integer userId) {
        this.userId = userId;
    }

    public Integer getProcessClass() {
        return processClass;
    }

    public void setProcessClass(Integer processClass) {
        this.processClass = processClass;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getHasGroupTypeCount() {
        return hasGroupTypeCount;
    }

    public void setHasGroupTypeCount(Integer hasGroupTypeCount) {
        this.hasGroupTypeCount = hasGroupTypeCount;
    }

}

==> beast-privilege-api-3.0-GS-20250709.081401-2-sources.jar: com/thebeastshop/privilege/cond/StoremanTaskmanagerDetailCond.java <==
package com.thebeastshop.privilege.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.List;

/**
 * Created by gensheng.ye on 2022/8/30.
 */
public class StoremanTaskmanagerDetailCond extends BaseQueryCond {

    private Integer taskId;



    /*
    渠道
    */
    private List<String> channelCodes;

    /*
     是否指派
     */
    private Integer assigned;


    /*
       手机号
     */
    private String mobile;

    /*
      负责人
     */
    private Integer userId;

    private Integer processClass;

    private Integer type;

    private Integer hasGroupTypeCount;

    private Integer memberId;


    public Integer getTaskId() {
        return taskId;
    }

    public void setTaskId(Integer taskId) {
        this.taskId = taskId;
    }


    public List<String> getChannelCodes() {
        return channelCodes;
    }

    public void setChannelCodes(List<String> channelCodes) {
        this.channelCodes = channelCodes;
    }

    public Integer getAssigned() {
        return assigned;
    }

    public void setAssigned(Integer assigned) {
        this.assigned = assigned;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Integer getUserId() {
        return userId;
    }

    public void setUserId(Integer userId) {
        this.userId = userId;
    }

    public Integer getProcessClass() {
        return processClass;
    }

    public void setProcessClass(Integer processClass) {
        this.processClass = processClass;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getHasGroupTypeCount() {
        return hasGroupTypeCount;
    }

    public void setHasGroupTypeCount(Integer hasGroupTypeCount) {
        this.hasGroupTypeCount = hasGroupTypeCount;
    }

    public Integer getMemberId() {
        return memberId;
    }

    public void setMemberId(Integer memberId) {
        this.memberId = memberId;
    }

}
